# Core API Reference

This module contains the main classes for interacting with the Census Bureau API.

---

## CenDatHelper

::: cendat.CenDatHelper
    options:
        show_root_heading: true
        show_source: true
        heading_level: 3
        members_order: source

---

## CenDatResponse

::: cendat.CenDatResponse
    options:
        show_root_heading: true
        show_source: true
        heading_level: 3
        members_order: source
